/**
 * \file main.c
 * Main code
 * 
 * Main file for USB Mass storage device.
 * 
 * AT91SAM7S-128 USB Mass Storage Device with SD Card by Michael Wolf\n
 * Copyright (C) 2008 Michael Wolf\n\n
 * 
 * This program is free software: you can redistribute it and/or modify\n
 * it under the terms of the GNU General Public License as published by\n
 * the Free Software Foundation, either version 3 of the License, or\n
 * any later version.\n\n
 * 
 * This program is distributed in the hope that it will be useful,\n
 * but WITHOUT ANY WARRANTY; without even the implied warranty of\n
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n
 * GNU General Public License for more details.\n\n
 * 
 * You should have received a copy of the GNU General Public License\n
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.\n
 * 
 */
 
/**
 * 
 * \mainpage AT91SAM7S128 USB Mass Storage Device with SD card
 * 
 * \version 0.10a
 * 
 * \section intro_sec Introduction
 *
 * This documentation is generated by Doxygen and documents a example source code
 * to implement an USB mass storage device on Atmel AT91SAM7S-128 using a SD card as
 * storage medium.\n\n
 *
 * The code was taken from another project and therefore requires some basic hardware
 * to run.\n
 * Especially the code related to the power button needs to be changed for your requirements.\n
 * \see Schematic for hardware details.\n\n
 * All USB functions are based on Atmels USB MSD framework. But this code has been modified and
 * reduced to a minimum requirment to save resources and make the code more readable.\n
 * Transfer rates are not very fast, bottleneck here is the bulk endpoint size of only 
 * 64 byte.\n\n
 * 
 * Code uses 20772 bytes program memory and 4312 bytes RAM.\n\n
 * 
 * Debugging output for all parts of the code can be configured in file trace.h \n
 * Using the debugging unit with 115200 Baud 8N1
 *  
 * These documentation pages are generated regularly from the currect source code.
 * 
 * For questions, bug reports or problems about contact me, Michael, at <a href="mailto:michael@mictronics.de">michael@mictronics.de</a>
 *
 * \author  Michael Wolf
 * \see http://www.mictronics.de
 * 
 * \image html SAM7_USB_MSD_example_schematic.png "Example Schematic"
 * 
 * AT91SAM7S-128 USB Mass Storage Device with SD Card by Michael Wolf\n
 * Copyright (C) 2008 Michael Wolf\n\n
 * 
 * This program is free software: you can redistribute it and/or modify\n
 * it under the terms of the GNU General Public License as published by\n
 * the Free Software Foundation, either version 3 of the License, or\n
 * any later version.\n\n
 * 
 * This program is distributed in the hope that it will be useful,\n
 * but WITHOUT ANY WARRANTY; without even the implied warranty of\n
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n
 * GNU General Public License for more details.\n\n
 * 
 * You should have received a copy of the GNU General Public License\n
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.\n
 * 
 */ 

#include "hardware_conf.h"


#include "trace.h"
#include "interrupt_utils.h"

#include "serial.h"

#include "rprintf.h"

#include "main.h"
#include "serial_us1.h"


AT91PS_PIO  pPIO = AT91C_BASE_PIOA;     // PIO controller
AT91PS_PMC  pPMC = AT91C_BASE_PMC;      // Power management controller
extern AT91PS_AIC  pAIC;      //!< Interrupt controller


/**
 * The main function.
 * 
 * \return Zero
 * 
 */
int main (void) {
 
    *AT91C_WDTC_WDMR = AT91C_WDTC_WDDIS;
    
    init_lowlevel_io(); // init all IO pins and ports

    usart0_init();  // init USART0
    TRACE("Powering up...\n\n");
	
	usart0_putchar('A');

	uart1_init(9600L,1);
	
	while(1)
	{
		continue;
	}
   return 0;   // we should never reach this return
}   // end of int main(void)


/**
 * IO initialization
 * 
 * Initialization for IO pins and ports and internal hardware.
 * 
 */
void init_lowlevel_io(void)
{

    // enable reset-button
    *AT91C_RSTC_RMR = ( 0xA5000000 | AT91C_RSTC_URSTEN );
    
    *AT91C_PMC_PCER =   (1 << AT91C_ID_PIOA) |  // Enable Clock for PIOA
    										(1 << AT91C_ID_PIOB) |  // Enable Clock for PIOB
                        (1 << AT91C_ID_IRQ0);  // Enable Clock for IRQ0



}   // end of void init_lowlevel_io(void)

