
#include "AT91SAM7X256.h"
#include "serial_us1.h"
#include "hardware_conf.h"
#include "interrupt_utils.h"
void Usart_c_irq_handler(void);
#define BR    115200                        /* Baud Rate */

#define BRD  (MCK/16/BR)                    /* Baud Rate Divisor */

void uart1_init(long BaudRate, int interrupt) 
{  
	UART1_PERCLOCK_Init(); // Initialisation du periph clock
  
	*AT91C_PIOA_PDR = 	AT91C_PA5_RXD1 |        /* Enable RxD0 Pin */
  						AT91C_PA6_TXD1;         /* Enalbe TxD0 Pin */

	*AT91C_US1_CR = AT91C_US_RSTRX |          /* Reset Receiver      */
                  	AT91C_US_RSTTX |          /* Reset Transmitter   */
                  	AT91C_US_RXDIS |          /* Receiver Disable    */
                  	AT91C_US_TXDIS;           /* Transmitter Disable */

	*AT91C_US1_MR = AT91C_US_USMODE_NORMAL |  /* Normal Mode */
                  	AT91C_US_CLKS_CLOCK    |  /* Clock = MCK */
                  	AT91C_US_CHRL_8_BITS   |  /* 8-bit Data  */
                  	AT91C_US_PAR_NONE      |  /* No Parity   */
                  	AT91C_US_NBSTOP_1_BIT;    /* 1 Stop Bit  */

  	*AT91C_US1_BRGR = (MCK / 16 / BaudRate);  /* Baud Rate Divisor */
  
  	*AT91C_US1_IER = AT91C_US_RXRDY;//interrupt mask
  	if(interrupt)
  		usrt1_init_interrupt();//permettre les interruptions

  
  *AT91C_US1_CR = 	AT91C_US_RXEN  |          /* Receiver Enable     */
                  	AT91C_US_TXEN;            /* Transmitter Enable  */ 
}

int uart1_putc(int ch) 
{
	while (!(*AT91C_US1_CSR & AT91C_US_TXEMPTY));   /* Wait for Empty Tx Buffer */
	*AT91C_US1_THR = ch;	
	return ch;
}	

int uart1_putchar(int ch) 
{ 
  if (ch == '\n')  
  {
    uart1_putc( '\r' );
  }
  return uart1_putc(ch);
}

int uart1_puts(char* s)
{
	while (*s) uart1_putchar(*s++);
	return 0;
}

int uart1_kbhit(void)
{
	if (*AT91C_US1_CSR & AT91C_US_RXRDY) 
	{
		return 1;
	}
	else 
	{
		return 0;
	}
}

int uart1_getc(void)
{    
  while (!(*AT91C_US1_CSR & AT91C_US_RXRDY));   /* Wait for Full Rx Buffer */
  return (*AT91C_US1_RHR);                      /* Read Character */
}

void uart1_gets(char *s,int view)
{
	int car;
	
	do
	{
		car = uart1_getc();
		if(view)
		{
			uart1_putc(car);	
		}
		*s = car;
		s++;
	}
	while(car != 0x0d);
	*(s-1) = 0x00;
}

void usrt1_init_interrupt(void)
{
	unsigned int mask ;
	
	mask = (0x1 << AT91C_ID_US1);
    //* Disable the interrupt on the interrupt controller
    *AT91C_AIC_IDCR = mask ;
    //* Save the interrupt handler routine pointer and the interrupt priority
    AT91C_AIC_SVR[AT91C_ID_US1] = (unsigned int) Usart_c_irq_handler ;
    //* Store the Source Mode Register
    AT91C_AIC_SMR[AT91C_ID_US1] = (AT91C_AIC_SRCTYPE_INT_HIGH_LEVEL | USART_INTERRUPT_LEVEL);
    //* Clear the interrupt on the interrupt controller
    *AT91C_AIC_ICCR = mask ;
    
    *AT91C_AIC_IECR = (0x1 << AT91C_ID_US1);//Enable interrupt
    
}


